import 'package:flutter/material.dart';
import '../marker_data.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';
import 'package:fl_chart/fl_chart.dart';

class MapContainerWidget extends StatefulWidget {
  final List<MarkerTemplate> markerList;

  const MapContainerWidget({Key? key, required this.markerList}) : super(key: key);

  @override
  _MapContainerWidgetState createState() => _MapContainerWidgetState();
}

class _MapContainerWidgetState extends State<MapContainerWidget> {

  MarkerTemplate? selectedMarker;

  @override
  Widget build(BuildContext context) {

    // NB: temporary test data
    final List<FlSpot> chartData = [
      FlSpot(0, 10),
      FlSpot(1, 20),
      FlSpot(2, 30),
      FlSpot(3, 40),
    ];
    double barWidth = 30; // Width for bars in bar chart
    const double contPadding = 30; // Container padding space

    double screenWidth = MediaQuery.of(context).size.width;
    double boxWidth = 0.9;
    double boxHeight = 1.5;

    return Column(
      children: [
        Container(
          width: screenWidth * boxWidth,
          height: screenWidth * boxHeight,
          color: Colors.blue,
          child: FlutterMap(
            options: MapOptions(
              center: LatLng(60.7666, 10.8471),
              zoom: 9.0,
            ),
            children: [
              TileLayer(
                urlTemplate: "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
                subdomains: const ['a', 'b', 'c'],
              ),
              MarkerLayer(
                markers: widget.markerList.map((MarkerTemplate markerTemplate) {
                  return Marker(
                    width: markerTemplate.size,
                    height: markerTemplate.size,
                    point: markerTemplate.location,
                    builder: (ctx) => GestureDetector(
                      onTap: () {
                        setState(() {
                          selectedMarker = markerTemplate;
                        });
                        // NB: temporary print
                        print('Icon tapped: ${selectedMarker?.size}');
                      },
                      child: Image.asset(
                        'assets/icons/circle-red.png',
                        // Path to your custom icon asset
                        color: markerTemplate.color,
                        width: markerTemplate.size,
                        height: markerTemplate.size,
                      ),
                    ),
                  );
                }).toList(),
              ),
              /*PolygonLayer(
                  polygons: [
                    Polygon(
                      points: [
                        LatLng(60.7600, 10.8000),
                        LatLng(60.7600, 11.0000),
                        LatLng(60.7000, 11.0000),
                        LatLng(60.7000, 10.8000),
                      ],
                      color: Colors.blue,
                      isFilled: true,
                    ),
                  ],
                ),*/
            ],
          ),
        ),
        const SizedBox(height: contPadding), // Padding between containers
        Container(
          //width: screenWidth * boxWidth,
          height: screenWidth * boxHeight*1.5, // NB: make dynamic
          color: const Color(0xFF64B5F6),
          child: Align(
            alignment: Alignment.topLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 20, left: 20), // Edge padding, text
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Text(
                    'Ice stats',
                    style: TextStyle(fontSize: 30, color: Colors.black),
                  ),
                  Text(
                    'Latitude: ${selectedMarker?.geoData.latitude}',
                    style: const TextStyle(fontSize: 20, color: Colors.black),
                  ),
                  Text(
                    'Longitude: ${selectedMarker?.geoData.longitude}',
                    style: const TextStyle(fontSize: 20, color: Colors.black),
                  ),
                  const SizedBox(height: contPadding),
                  SizedBox(
                    width: screenWidth-screenWidth/10,
                    height: 200,
                    child: LineChart(
                      LineChartData(
                        backgroundColor: const Color(0xFFCAF0F8),
                        titlesData: FlTitlesData(
                          leftTitles: SideTitles(showTitles: true),
                          bottomTitles: SideTitles(showTitles: true),
                        ),
                        borderData: FlBorderData(
                          show: true,
                        ),
                        minX: 0,
                        maxX: 4,
                        minY: 0,
                        maxY: 50,
                        lineBarsData: [
                          LineChartBarData(
                            spots: chartData,
                            isCurved: true,
                            colors: [const Color(0xFF0077B6)],
                          ),
                        ],
                      ),
                    ),
                  ),
                  const SizedBox(height: contPadding),
                  SizedBox(
                    width: screenWidth-screenWidth/10,
                    height: 200,
                    child: BarChart(
                      BarChartData(
                        alignment: BarChartAlignment.spaceAround,
                        maxY: 20, // Maximum y-axis value
                        barTouchData: BarTouchData(enabled: false),
                        titlesData: FlTitlesData(
                          bottomTitles: SideTitles(
                            showTitles: true,
                            getTextStyles: (value) => const TextStyle(color: Colors.black, fontSize: 14),
                            margin: 10,
                            getTitles: (value) {
                              switch (value.toInt()) {
                                case 0:
                                  return 'Placeholder1';
                                case 1:
                                  return 'Placeholder2';
                                case 2:
                                  return 'Placeholder3';
                                default:
                                  return '';
                              }
                            },
                          ),
                          leftTitles: SideTitles(
                            showTitles: true,
                            getTextStyles: (value) => const TextStyle(color: Colors.black, fontSize: 14),
                            margin: 10,
                            reservedSize: 30,
                            interval: 5,
                          ),
                        ),
                        borderData: FlBorderData(
                          show: true,
                          border: Border.all(color: Colors.black, width: 1),
                        ),
                        barGroups: [
                          BarChartGroupData(
                            x: 0,
                            barRods: [
                              BarChartRodData(
                                y: 15, // Bar height
                                width: barWidth, // Bar width
                              ),
                            ],
                          ),
                          BarChartGroupData(
                            x: 1,
                            barRods: [
                              BarChartRodData(
                                y: 10,
                                width: barWidth,
                              ),
                            ],
                          ),
                          BarChartGroupData(
                            x: 2,
                            barRods: [
                              BarChartRodData(
                                y: 18,
                                width: barWidth,
                              ),
                            ],
                          ),
                        ],
                      ),
                    )
                  )
                ],
              ),
            ),
          ),
        ),
      ],
    );
  }
}
